# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "RoleStatusEnum",
    },
)


class RoleStatusEnum(proto.Message):
    r"""Wrapper message for
    [RoleStatus][google.ads.admanager.v1.RoleStatusEnum.RoleStatus]

    """

    class RoleStatus(proto.Enum):
        r"""The status of the role.

        Values:
            ROLE_STATUS_UNSPECIFIED (0):
                No value specified.
            ACTIVE (1):
                Role is active.
            INACTIVE (2):
                Role is inactive.
        """
        ROLE_STATUS_UNSPECIFIED = 0
        ACTIVE = 1
        INACTIVE = 2


__all__ = tuple(sorted(__protobuf__.manifest))
